#
# spec file for package yubikey-manager-qt
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define bname ykman-gui
Name:           yubikey-manager-qt
Version:        1.2.5
Release:        1.6
Summary:        Graphical application for configuring a YubiKey
License:        BSD-2-Clause
Group:          Productivity/Security
URL:            https://developers.yubico.com/yubikey-manager-qt/Releases
Source0:        https://developers.yubico.com/yubikey-manager-qt/Releases/%{name}-%{version}.tar.gz
Source1:        https://developers.yubico.com/yubikey-manager-qt/Releases/%{name}-%{version}.tar.gz.sig
Source2:        yubikey-manager-qt.keyring
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Qml)
BuildRequires:  pkgconfig(Qt5Quick)
BuildRequires:  pkgconfig(Qt5QuickControls2)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(python3)
Requires:       libqt5-qtgraphicaleffects
Requires:       libqt5-qtquickcontrols
Requires:       libqt5-qtquickcontrols2
Requires:       python3-pyotherside
Requires:       python3-yubikey-manager >= 4.0.7

%description
A graphical application for configuring a YubiKey over all transport modes..

%prep
%setup -q -n %{name}
sed -i 's|yubikey-manager==|yubikey-manager>=|' requirements.txt
# Fix build for Leap 15 and SLE 15
sed -i 's|python |python3 |g' ykman-cli/ykman-cli.pro
sed -i 's|python |python3 |g' ykman-gui/ykman-gui.pro

%build
%qmake5
%make_build

%install
make install INSTALL_ROOT="%{buildroot}";
mkdir -p %{buildroot}%{_datadir}/pixmaps
install -p -m 0644 resources/icons/ykman.png %{buildroot}%{_datadir}/pixmaps/
%suse_update_desktop_file -i %{bname} System Security

%files
%doc NEWS README
%license COPYING
%{_bindir}/%{bname}
%{_datadir}/applications/%{bname}.desktop
%{_datadir}/pixmaps/ykman.png

%changelog
* Fri Mar  3 2023 Dirk Müller <dmueller@suse.com>
- update to 1.2.5:
  * Compatibility update for ykman 5.0.1.
  * Update to Python 3.11.
  * Update product images.
- add keyring for gpg validation
* Mon Nov  1 2021 Torsten Gruner <simmphonie@opensuse.org>
- Update to version 1.2.4 (released 2021-10-26)
  * Update device names and images.
  * PIV: Fix import of certificate.
* Tue May 18 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.2.3
  * Improved error handling when using Security Key Series devices.
  * PIV: Fix generation of certificate in slot 9c.
* Thu May  6 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.2.2
  * Fix detection of YubiKey Plus
  * Compatibility update for yubikey-manager 4.0
  * Bugfix: Device caching with multiple devices
  * Drop dependencies on libusb and libykpers.
  * Add additional product names and images
* Mon Aug 17 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.1.5
  * Add support for YubiKey 5C NFC
* Tue Feb 25 2020 Cristian Rodríguez <crrodriguez@opensuse.org>
- Update to version 1.1.4
  * OTP: Add option to upload YubiOTP credential to YubiCloud
  * Linux: Show hint about pcscd service if opening device fails
  * Bugfix: Signal handling now compatible with Python 3.8
- Set CONFIG=+hide_symbols so the compiler can generate better
  and smaller code knowing that no symbols need to be visible.
* Wed Aug 21 2019 simmphonie@opensuse.org
- Version 1.1.3 (released 2019-08-20)
  * Add suppport for YubiKey 5Ci
  * PIV: Use UTC time for self-signed certificates
- Version 1.1.2b (released 2019-06-26)
  * macOS: Fix build problem that caused communication with the OTP application to fail
* Sat Jun 29 2019 Karol Babioch <kbabioch@suse.com>
- Version 1.1.2 (released 2019-06-24)
  * Add support for new YubiKey Preview
  * PIV: The popup for the management key now have a "Use default" option
  * Windows: Fix issue with importing PIV certificates
  * Bugfix: generate static password now works correctly
* Mon Mar 11 2019 Karol Babioch <kbabioch@suse.de>
- Version 1.1.1 (released 2019-03-11)
  * PIV: On import, do not always verify that the certifcate and private key
    matches, since it may require the PIN
  * PIV: Report if private key or certificate was imported
  * PIV: Improve handling of malformed certificates
  * PIV: Allow uppercase characters in management key input field
- Fixed path issue with setup macro during build
* Wed Jan  9 2019 Karol Babioch <kbabioch@suse.de>
- Update to version 1.1.0 (released 2019-01-09):
  * Add support for Security Key NFC
  * Add support for managing PIV Application
  * Bugfix: OATH-HOTP credentials was always configured with 6 digits
  * UI: Replace Succes-popups with Snackbar-messages
  * UX: Drop confirmation prompt for OTP Swap Slots
* Tue Nov 13 2018 Karol Babioch <kbabioch@suse.com>
- Fixed dependency issues:
  * python3-pyotherside (explicitly require python3 module)
  * libqt5-qtgraphicaleffects (bsc#1115816)
  * libqt5-qtquickcontrols & libqt5-qtquickcontrols2 (bsc#1115595)
* Wed Oct 10 2018 Karol Babioch <kbabioch@suse.com>
- Bumped required version of yubikey-manager to 1.0.1
* Wed Oct 10 2018 Karol Babioch <kbabioch@suse.com>
- Version 1.0.1 (released 2018-10-10)
  * Support for YubiKey 5A
  * Bugfix: Show picture for FIDO U2F Security key
  * Bugfix: Swapping OTP slots or deleting OTP a slot configuration now reloads the view
  * Bugfix: Under some conditions the wrong device info was shown
* Thu Sep 27 2018 Karol Babioch <kbabioch@suse.com>
- Version 1.0.0 (released 2018-09-24)
  * Completely new UI
  * Support for YubiKey 5 Series
  * Support for configuring NFC and USB interfaces
  * Linux: Release as AppImage (experimental)
* Wed Jul 11 2018 kbabioch@suse.com
- Version 0.5.2 (released 2018-07-09)
  * Support for YubiKey FIPS.-
- Applied spec-cleaner
- Adjusted setup macro, since source tarball does not contain a
  top-level directory (i.e. tar bomb)
* Wed May  9 2018 kbabioch@suse.com
- Version 0.5.1:
  * Support changing USB interfaces for YubiKey Preview.
  * OATH-HOTP: Show correct error message on too long secret keys.
  * CLI: Give correct exit codes.
* Tue Apr 17 2018 kbabioch@suse.com
- Version 0.5.0:
  * Support for configuring YubiKeys with FIDO2.
  * OTP: Configuring HOTP now correctly supports 8 or 6 characters.
  * Static password: Any character can now be used in a static password.
  * UI: New header with help-link added.
  * New icon.
- Cleaned up spec file (spec-cleaner)
* Tue Apr  3 2018 t.gruner@katodev.de
- Fix build for Leap 15 and SLE 15
* Wed Mar 14 2018 meissner@suse.com
- require the libqt5-qtquickcontrols for the QML Dialog and Controls.
  (bsc#1085147)
* Thu Mar  1 2018 meissner@suse.com
- add python buildrequires.
* Wed Jan  3 2018 t.gruner@katodev.de
- Version 0.4.0
  - Update CLI version to ykman 0.5.0
  - Now requires ykman version >= 0.5.0
  - Features:
  - Now differentiates between disabled and unavailable features
  - Added --log-level CLI option with same function as --log-level option to ykman version 0.5.0; see ykman --help for usage
  - Bufixes:
  - Made main view and Configure Connections dialog respond to resizing window
* Fri Dec  1 2017 t.gruner@katodev.de
- Initial release version 0.3.2
